@@ -45,18 +45,19 @@
 #' @importFrom systemfonts match_font
 #' @export
 dsvg <- function(file = "Rplots.svg", width = 6, height = 6, bg = "white",
-                pointsize = 12, standalone = TRUE, setdims = TRUE, canvas_id = "svg_1",
-                fonts = list()) {
+                 pointsize = 12, standalone = TRUE, setdims = TRUE, canvas_id = "svg_1",
+                 fonts = list()) {
 
-  fonts_list <- validated_fonts( fonts )
+  fonts_list <- validated_fonts(fonts)
 
-  invisible(DSVG_(file=file, width=width, height=height, bg=bg,
-                  pointsize=pointsize,
-                  standalone=standalone,
-                  setdims=setdims,
-                  canvas_id=canvas_id,
-                  aliases = list(system = fonts_list)
-                  )
-            )
+  invisible(DSVG_(
+    filename = file,
+    width = width, height = height,
+    canvas_id = canvas_id,
+    standalone = standalone, setdims = setdims,
+    pointsize = pointsize,
+    bg = bg,
+    aliases = list(system = fonts_list)
+  ))
 }
 
