@@ -11,24 +11,23 @@ GeomInteractivePointrange <- ggproto(
   "GeomInteractivePointrange",
   GeomPointrange,
   default_aes = add_default_interactive_aes(GeomPointrange),
-  draw_key = function(data, params, size) {
-    gr <- GeomPointrange$draw_key(data, params, size)
-    add_interactive_attrs(gr, data, data_attr = "key-id")
-  },
+  parameters = interactive_geom_parameters,
+  draw_key = interactive_geom_draw_key,
   draw_panel = function(data,
                         panel_params,
                         coord,
                         fatten = 4,
-                        flipped_aes = FALSE) {
+                        flipped_aes = FALSE, 
+                        .ipar = IPAR_NAMES) {
     if (is.null(data[[flipped_names(flipped_aes)$y]]))
       return(
-        GeomInteractiveLinerange$draw_panel(data, panel_params, coord, flipped_aes = flipped_aes)
+        GeomInteractiveLinerange$draw_panel(data, panel_params, coord, flipped_aes = flipped_aes, .ipar = .ipar)
       )
 
     ggname("geom_pointrange", gTree(
       children = gList(
-        GeomInteractiveLinerange$draw_panel(data, panel_params, coord, flipped_aes = flipped_aes),
-        GeomInteractivePoint$draw_panel(transform(data, size = size * fatten), panel_params, coord)
+        GeomInteractiveLinerange$draw_panel(data, panel_params, coord, flipped_aes = flipped_aes, .ipar = .ipar),
+        GeomInteractivePoint$draw_panel(transform(data, size = size * fatten), panel_params, coord, .ipar = .ipar)
       )
     ))
   }
