@@ -30,10 +30,13 @@
 #' @importFrom rlang eval_tidy
 labeller_interactive <- function(.mapping = NULL, ...) {
   # get interactive aesthetics, plus a label parameter
-  ipar = c(IPAR_NAMES, "label")
+  dots <- list(...)
+  extra_interactive_params <- c(dots$extra_interactive_params, "label")
+  ipar <- get_default_ipar(extra_interactive_params)
   ip <- get_interactive_attrs(.mapping, ipar = ipar)
+  dots$extra_interactive_params <- NULL
   # create ggplot2 labeller
-  lbl_fun <- labeller(...)
+  lbl_fun <- do.call(labeller, dots)
 
   # helper to evaluate the aesthetics and return a data frame
   interactive_to_df <- function(data) {
@@ -59,19 +62,17 @@ labeller_interactive <- function(.mapping = NULL, ...) {
         data$.label <- x
         # get all interactive parameters as a data frame
         ip_data <- interactive_to_df(data)
-        ip_data <- force_interactive_aes_to_char(ip_data, ipar = ipar)
 
         # for each factor element
         imap(x, function(x, i) {
-          if (inherits(x, "interactive_label")) {
-            # already a label_interactive
-            x
-          } else {
+          lbl <- x
+          if (!inherits(lbl, "interactive_label")) {
             # create a label_interactive, applying the interactive parameters
-            args <- list(label = x)
+            args <- list(label = x, extra_interactive_params = extra_interactive_params)
             args <- copy_interactive_attrs(ip_data, args, rows = i, ipar = ipar)
-            do.call(label_interactive, args)
+            lbl <- do.call(label_interactive, args)
           }
+          lbl
         })
       })
     }
